@@ -14,7 +14,6 @@ UnpauseQueue <- function(project) {
   projectId <- ValidateProject(project)
   routeString <- UrlJoin("projects", projectId, "autopilot")
   body <- jsonlite::unbox(data.frame(command = 'start'))
-  response <- DataRobotPOST(routeString, addUrl = TRUE,
-                               body = body, encode = "json")
+  response <- DataRobotPOST(routeString, body = body, encode = "json")
   message(paste("Queue for project", projectId, "unpaused"))
 }
